@@ -2,6 +2,8 @@ try:
     __import__('pkg_resources').declare_namespace(__name__)
 except ImportError:
     __path__ = __import__('pkgutil').extend_path(__path__, __name__)
+ 
+from .middleware import *
 
-from .errors import ErrorResponse
-from .middleware import Ok
\ No newline at end of file
+if __name__ == '__main__':
+    pass
